[llvm-bugs] [Bug 32182] [MIPS] Error: unknown pseudo-op: `.nan'

via llvm-bugs llvm-bugs at lists.llvm.org
Thu Mar 9 17:14:17 PST 2017


http://bugs.llvm.org/show_bug.cgi?id=32182

Sean Bruno <sbruno at freebsd.org> changed:

           What    |Removed                     |Added
----------------------------------------------------------------------------
         Resolution|---                         |FIXED
             Status|NEW                         |RESOLVED

--- Comment #4 from Sean Bruno <sbruno at freebsd.org> ---
Ok, I found the knob to turn.  Thanks!

Index: lib/Driver/ToolChains/FreeBSD.cpp
===================================================================
--- lib/Driver/ToolChains/FreeBSD.cpp   (revision 297391)
+++ lib/Driver/ToolChains/FreeBSD.cpp   (working copy)
@@ -316,7 +316,8 @@
   // When targeting 32-bit platforms, look for '/usr/lib32/crt1.o' and fall
   // back to '/usr/lib' if it doesn't exist.
   if ((Triple.getArch() == llvm::Triple::x86 ||
-       Triple.getArch() == llvm::Triple::ppc) &&
+       Triple.getArch() == llvm::Triple::ppc ||
+       Triple.getArch() == llvm::Triple::mips) &&
       D.getVFS().exists(getDriver().SysRoot + "/usr/lib32/crt1.o"))
     getFilePaths().push_back(getDriver().SysRoot + "/usr/lib32");
   else
Index: lib/Driver/ToolChains/Gnu.cpp
===================================================================
--- lib/Driver/ToolChains/Gnu.cpp       (revision 297391)
+++ lib/Driver/ToolChains/Gnu.cpp       (working copy)
@@ -2290,11 +2290,13 @@
     return true;
   case llvm::Triple::mips64:
   case llvm::Triple::mips64el:
     // Enabled for Debian mips64/mips64el only. Other targets are unable to
unable to
     // distinguish N32 from N64.
-    if (getTriple().getEnvironment() == llvm::Triple::GNUABI64)
+    if (getTriple().getEnvironment() == llvm::Triple::GNUABI64 ||
+        getTriple().getOS() == llvm::Triple::FreeBSD)
       return true;
-    return false;
+    else
+      return false;
   default:
     return false;
   }
@@ -2290,11 +2290,13 @@
   case llvm::Triple::mips64:
   case llvm::Triple::mips64el:
-    // Enabled for Debian mips64/mips64el only. Other targets are unable to
+    // Enabled for Debian/FreeBSD mips64/mips64el only. Other targets are
unable to
     // distinguish N32 from N64.

-- 
You are receiving this mail because:
You are on the CC list for the bug.
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.llvm.org/pipermail/llvm-bugs/attachments/20170310/ba7e1ee1/attachment.html>


More information about the llvm-bugs mailing list